Stan Math Library: stan/math/fwd/scal/fun/acos.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

acos.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_ACOS_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_ACOS_HPP
3
4 #include <stan/math/fwd/core.hpp>
5 #include <stan/math/prim/scal/fun/square.hpp>
6 #include <cmath>
7
8 namespace stan {
9 namespace math {
10
11 template <typename T>
12 inline
13 fvar<T>
14 acos(const fvar<T>& x) {
15 using std::acos;
16 using std::sqrt;
17 using stan::math::square;
18 return fvar<T>(acos(x.val_), x.d_ / -sqrt(1 - square(x.val_)));
19 }
20
21 }
22 }
23 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan::math::sqrt
fvar< T > sqrt(const fvar< T > &x)
Definition: sqrt.hpp:15
stan
Definition: log_sum_exp.hpp:8
square.hpp
stan::math::square
fvar< T > square(const fvar< T > &x)
Definition: square.hpp:15
stan::math::acos
var acos(const var &a)
Return the principal value of the arc cosine of a variable, in radians (cmath).
Definition: acos.hpp:59
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::acos
fvar< T > acos(const fvar< T > &x)
Definition: acos.hpp:14
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.